**********************************
The sherpa.astro.background module
**********************************

.. currentmodule:: sherpa.astro.background

.. automodule:: sherpa.astro.background

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      add_response
      get_response_for_pha
